embassy-rp

Crates

git

Versions

rp235xa

Flavors

BufferedUartRx

Struct BufferedUartRx 

pub struct BufferedUartRx<'d> { /* private fields */ }
Buffered UART RX handle.

Implementations

Source

impl<'d> BufferedUartRx<'d>

pub fn new<T: Instance>( _uart: Peri<'d, T>, rx: Peri<'d, impl RxPin<T>>, _irq: impl Binding<T::Interrupt, BufferedInterruptHandler<T>>, rx_buffer: &'d mut [u8], config: Config, ) -> Self

Create a new buffered UART RX.

pub fn new_with_rts<T: Instance>( _uart: Peri<'d, T>, rx: Peri<'d, impl RxPin<T>>, rts: Peri<'d, impl RtsPin<T>>, _irq: impl Binding<T::Interrupt, BufferedInterruptHandler<T>>, rx_buffer: &'d mut [u8], config: Config, ) -> Self

Create a new buffered UART RX with flow control.

pub async fn read(&mut self, buf: &mut [u8]) -> Result<usize, Error>

Read from UART RX buffer.

Waits until at least one byte is available, then reads as many bytes as are available (up to buf.len()) and returns the number of bytes read.

pub fn blocking_read(&mut self, buf: &mut [u8]) -> Result<usize, Error>

Read from UART RX buffer blocking execution until done.

pub async fn fill_buf(&mut self) -> Result<&[u8], Error>

Wait until data is available in the RX buffer, and return a slice to it.

Call consume afterwards to mark bytes as read.

pub fn consume(&mut self, amt: usize)

Mark amt bytes returned by fill_buf as read.

pub fn read_ready(&mut self) -> Result<bool, Error>

Check whether data is available in the RX buffer, i.e. whether a read would not block.